@@ -5,7 +5,6 @@ from dateutil.relativedelta import relativedelta
 import time
 import json
 from copy import deepcopy
-from collections import defaultdict
 
 from colorama import Style, Fore
 
@@ -30,9 +29,6 @@ class LiveClient(WebSocketApp):
         self.logger = self.parent_app.logger
         self.disconnect_flag = False
         self.heartbeat_check_thread = Thread(target=self.check_heartbeat, daemon=True)
-        self.trade_callback = None
-        self.bar_callback = None
-        self.bidask_callback = None
         # if self.parent_app.live_port == 8086 or self.parent_app.live_port == 8084:
         #     # self.heartbeat_check_thread.start()
         #     pass
@@ -72,8 +68,7 @@ class LiveClient(WebSocketApp):
         return time_series[start_gap_index], time_series[start_gap_index+1]
 
     def recover_from_time_missed(self, start_time, end_time):
-        self.logger.info(f"{Style.BRIGHT}{Fore.YELLOW}Initiating recovery from {Fore.GREEN}{start_time}{Fore.YELLOW} till {Fore.GREEN}{end_time}{Fore.YELLOW} "
-                         f"which are last green heartbeats from server...{Style.RESET_ALL}")
+        self.logger.info(f"{Style.BRIGHT}{Fore.YELLOW}Initiating recovery from {Fore.GREEN}{start_time}{Fore.YELLOW} till {Fore.GREEN}{end_time}{Fore.YELLOW} which are last green heartbeats from server...{Style.RESET_ALL}")
 
     def reconnect(self):
         self.close()
@@ -86,8 +81,7 @@ class LiveClient(WebSocketApp):
             is_td_connected = self.check_connection()
         return is_td_connected
 
-    def on_msg_func(self, *args):
-        message = args[-1]
+    def on_msg_func(self, message):
         msg = json.loads(message)
         if 'message' in msg.keys():
             self.handle_message_data(msg)
@@ -107,10 +101,8 @@ class LiveClient(WebSocketApp):
             if msg['message'] == 'HeartBeat':
                 self.handle_heartbeat(msg['timestamp'])
             elif msg['message'] == 'TrueData Real Time Data Service':  # Connection success message
-                # self.logger.info(f"{Style.BRIGHT}{Fore.WHITE}You have subscribed for {msg['maxsymbols']} "
-                #                  f"symbols across {msg['segments']} until {msg['validity']} with type of stream "
-                #                  f"as {msg['subscription']}...{Style.RESET_ALL}")
-                self.logger.warning(f"{Style.NORMAL}{Fore.BLUE}Connected successfully to {msg['message']}... {Style.RESET_ALL}")
+                # self.logger.info(f"{Style.BRIGHT}{Fore.WHITE}You have subscribed for {msg['maxsymbols']} symbols across {msg['segments']} until {msg['validity']} with type of stream as {msg['subscription']}...{Style.RESET_ALL}")
+                print(f"{Style.NORMAL}{Fore.BLUE}Connected successfully to {msg['message']}... {Style.RESET_ALL}")
                 self.subscription_type = msg['subscription']
             elif msg['message'] in ['symbols added', 'touchline']:
                 self.add_contract_details(msg['symbollist'])
@@ -130,9 +122,6 @@ class LiveClient(WebSocketApp):
             contract = contract_info.split(':')[0]
             for req_id in self.parent_app.symbol_mkt_id_map[contract.upper()]:
                 del self.parent_app.live_data[req_id]
-                del self.parent_app.touchline_data[req_id]
-                if '+' in self.subscription_type:
-                    del self.parent_app.min_live_data[req_id]
             del self.parent_app.symbol_mkt_id_map[contract.upper()]
 
     def add_contract_details(self, contracts_list):
@@ -140,6 +129,7 @@ class LiveClient(WebSocketApp):
             if contract_details is not None:
                 self.contract_mapping[int(contract_details[1])] = symbol = contract_details[0]
                 for ticker_id in self.parent_app.symbol_mkt_id_map[symbol]:
+                    # print(ticker_id)
                     self.parent_app.touchline_data[ticker_id].symbol_id = int(contract_details[1])
                     self.parent_app.touchline_data[ticker_id].timestamp = datetime.strptime(contract_details[2], '%Y-%m-%dT%H:%M:%S')
                     self.parent_app.touchline_data[ticker_id].symbol = symbol
@@ -159,9 +149,7 @@ class LiveClient(WebSocketApp):
                     self.parent_app.touchline_data[ticker_id].best_ask_price = float(contract_details[16])
                     self.parent_app.touchline_data[ticker_id].best_ask_qty = float(contract_details[17])
                     self.parent_app.live_data[ticker_id].populate_using_touchline(self.parent_app.live_data[ticker_id], self.parent_app.touchline_data[ticker_id])
-                    if '+' in self.subscription_type:
-                        self.parent_app.min_live_data[ticker_id].populate_using_touchline(self.parent_app.min_live_data[ticker_id], self.parent_app.touchline_data[ticker_id])
-                self.logger.info(f"Updated touchline data for {symbol} and related live data objects...")
+                # print(f"Updated touchline data for {symbol} and related live data objects...") #  self.logger.info
             else:
                 self.logger.debug(f'{Style.BRIGHT}{Fore.YELLOW}Probable repeated symbol...{Style.RESET_ALL}')
 
@@ -169,6 +157,7 @@ class LiveClient(WebSocketApp):
         try:
             symbol = self.contract_mapping[int(trade_tick[0])]
             for ticker_id in self.parent_app.symbol_mkt_id_map[symbol]:
+                # Assigning new data
                 self.parent_app.live_data[ticker_id].symbol_id = int(trade_tick[0])
                 self.parent_app.live_data[ticker_id].timestamp = datetime.strptime(trade_tick[1], '%Y-%m-%dT%H:%M:%S')  # Old format = '%m/%d/%Y %I:%M:%S %p'
                 self.parent_app.live_data[ticker_id].symbol = symbol
@@ -208,15 +197,10 @@ class LiveClient(WebSocketApp):
                         pass
                 except Exception as e:
                     self.logger.error(e)
-                if self.trade_callback:
-                    try:
-                        self.trade_callback(ticker_id, self.parent_app.live_data[ticker_id])
-                    except Exception as e:
-                        self.logger.error(f'{Style.BRIGHT}{Fore.RED}Encountered error with trade_callback - {type(e)} - {e}{Style.RESET_ALL}')
         except KeyError:
             pass
         except Exception as e:
-            self.logger.error(f'{Style.BRIGHT}{Fore.RED}Encountered error with tick feed - {type(e)}{Style.RESET_ALL}')
+            self.logger.error(f'{Style.BRIGHT}{Fore.RED}Encountered with tick feed - {type(e)}{Style.RESET_ALL}')
 
     def handle_bid_ask_data(self, bidask_tick):
         try:
@@ -229,73 +213,48 @@ class LiveClient(WebSocketApp):
                 self.parent_app.live_data[ticker_id].best_ask_price = float(bidask_tick[4])
                 self.parent_app.live_data[ticker_id].best_ask_qty = int(bidask_tick[5])
                 self.parent_app.live_data[ticker_id].tick_type = 2
-                if self.bidask_callback:
-                    try:
-                        self.bidask_callback(ticker_id, self.parent_app.live_data[ticker_id])
-                    except Exception as e:
-                        self.logger.error(f'{Style.BRIGHT}{Fore.RED}Encountered error with bidask_callback - {type(e)} - {e}{Style.RESET_ALL}')
         except KeyError:
             pass
         except Exception as e:
-            self.logger.error(f'{Style.BRIGHT}{Fore.RED}Bid-ask feed error encountered ({type(e)})- {e}{Style.RESET_ALL}')
+            self.logger.error(f'{Style.BRIGHT}{Fore.RED}Bid-ask feed encountered - {e}{Style.RESET_ALL}')
 
     def handle_bar_data(self, bar_data):
         try:
             symbol = self.contract_mapping[int(bar_data[0])]
             for ticker_id in self.parent_app.symbol_mkt_id_map[symbol]:
-                if '+' in self.subscription_type:
-                    obj_to_edit = self.parent_app.min_live_data[ticker_id]
-                else:
-                    obj_to_edit = self.parent_app.live_data[ticker_id]
-                obj_to_edit.symbol_id = int(bar_data[0])
-                obj_to_edit.timestamp = datetime.strptime(bar_data[1], '%Y-%m-%dT%H:%M:%S')
-                obj_to_edit.symbol = symbol
-                obj_to_edit.open = float(bar_data[2])
-                obj_to_edit.high = bar_high = float(bar_data[3])
-                if bar_high > obj_to_edit.day_high:
-                    obj_to_edit.day_high = self.parent_app.touchline_data[ticker_id].high = bar_high
-                obj_to_edit.low = bar_low = float(bar_data[4])
-                if bar_low < obj_to_edit.day_low:
-                    obj_to_edit.day_low = self.parent_app.touchline_data[ticker_id].low = bar_low
-                obj_to_edit.close = self.parent_app.touchline_data[ticker_id].ltp = float(bar_data[5])
-                obj_to_edit.volume = float(bar_data[6])
-                obj_to_edit.oi = float(bar_data[7])
-                if self.bar_callback:
-                    try:
-                        self.bar_callback(ticker_id, obj_to_edit)
-                    except Exception as e:
-                        self.logger.error(f'{Style.BRIGHT}{Fore.RED}Encountered error with bar_callback - {type(e)} - {e}{Style.RESET_ALL}')
+                # Assigning new data
+                self.parent_app.live_data[ticker_id].symbol_id = int(bar_data[0])
+                self.parent_app.live_data[ticker_id].timestamp = datetime.strptime(bar_data[1], '%Y-%m-%dT%H:%M:%S')
+                self.parent_app.live_data[ticker_id].symbol = symbol
+                self.parent_app.live_data[ticker_id].open = float(bar_data[2])
+                self.parent_app.live_data[ticker_id].high = bar_high = float(bar_data[3])
+                if bar_high > self.parent_app.live_data[ticker_id].day_high:
+                    self.parent_app.live_data[ticker_id].day_high = self.parent_app.touchline_data[ticker_id].high = bar_high
+                self.parent_app.live_data[ticker_id].low = bar_low = float(bar_data[4])
+                if bar_low < self.parent_app.live_data[ticker_id].day_low:
+                    self.parent_app.live_data[ticker_id].day_low = self.parent_app.touchline_data[ticker_id].low = bar_low
+                self.parent_app.live_data[ticker_id].close = self.parent_app.touchline_data[ticker_id].ltp = float(bar_data[5])
+                self.parent_app.live_data[ticker_id].volume = float(bar_data[6])
+                self.parent_app.live_data[ticker_id].oi = float(bar_data[7])
         except KeyError:
             pass
         except Exception as e:
             self.logger.error(f'{Style.BRIGHT}{Fore.RED}Bar feed encountered - {e}{Style.RESET_ALL}')
 
-    def ws_error(self, *args):
-        error = args[-1]
+    def ws_error(self, error):
         if any(isinstance(error, conn_error) for conn_error in [ConnectionResetError, TimeoutError]):
             self.logger.error(f"Raising WS error = {error}")
             self.last_ping_tm = self.last_pong_tm = 0
 
-    # noinspection PyUnusedLocal
-    def ws_open(self, *args):
+    def ws_open(self):
         self.last_ping_tm = time.time()
         self.sock.ping()
         self.sock.settimeout(15)
         if self.parent_app.symbol_mkt_id_map:
-            old_symbol_map = temp_symbol_map = deepcopy(self.parent_app.symbol_mkt_id_map)  # temp_symbol_map is destructed while restarting the data
-            temp_symbol_map = dict(temp_symbol_map)
-            self.parent_app.symbol_mkt_id_map = defaultdict(set)
-            self.logger.debug(f'{list(temp_symbol_map.keys())} needs resuming here.')
-            while temp_symbol_map:
-                restart_symbols = list(temp_symbol_map.keys())
-                restart_req_ids = [temp_symbol_map[symbol].pop() for symbol in restart_symbols]
-                self.parent_app.start_live_data(restart_symbols, req_id=restart_req_ids)
-                temp_symbol_map = {symbol: symbol_set for (symbol, symbol_set) in temp_symbol_map.items() if symbol_set}
-            assert old_symbol_map == self.parent_app.symbol_mkt_id_map
-            self.logger.info(f'All streaming symbols have been resumed.')
+            print('Some data needs resuming here')
+            # print(self.parent_app.symbol_mkt_id_map)
 
-    # noinspection PyUnusedLocal
-    def ws_close(self, *args):
+    def ws_close(self):
         # self.logger.error('Live WebSocket Closed')
         self.sock.close()
         self.sock = None
